@@ -1,7 +1,11 @@
 from .environment.base import AbstractEnvironment, Environment
 from .environment.memory import MemoryEnvironment
 from .environment.text import TextEnvironment
-from .ingest.spreadsheet import read_csv_dataset, read_excel_dataset, pandas_to_env, pandas_to_env_with_id
+from .feature_extraction import (BaseVectorizer, SklearnVectorizer,
+                                 TextInstanceVectorizer)
+from .functions.vectorize import vectorize
+from .ingest.spreadsheet import (pandas_to_env, pandas_to_env_with_id,
+                                 read_csv_dataset, read_excel_dataset)
 from .instances.base import Instance, InstanceProvider
 from .instances.memory import DataPoint, DataPointProvider
 from .instances.text import TextInstance, TextInstanceProvider
@@ -22,5 +26,6 @@ __all__= [
     "LabelProvider",
     "MemoryLabelProvider",
     "SkLearnDataClassifier", "SkLearnVectorClassifier",
-    "read_csv_dataset", "read_excel_dataset", "pandas_to_env", "pandas_to_env_with_id"
+    "read_csv_dataset", "read_excel_dataset", "pandas_to_env", "pandas_to_env_with_id", 
+    "vectorize", "BaseVectorizer", "SklearnVectorizer", "TextInstanceVectorizer"
 ]
