@@ -33,6 +33,14 @@ InstanceInput = Union[InstanceProvider[IT, KT, DT, VT, RT], Iterable[Instance[KT
 class AbstractClassifier(ABC, Generic[IT, KT, DT, VT, RT, LT, LMT, PMT]):
     _name = "AbstractClassifier"
 
+    @abstractmethod
+    def get_label_column_index(self, label: LT) -> int:
+        raise NotImplementedError
+
+    @abstractmethod
+    def set_target_labels(self, labels: Iterable[LT]) -> None:
+        raise NotImplementedError
+
     @abstractmethod
     def predict_instances(self, 
                           instances: Iterable[Instance[KT, DT, VT, RT]], 
